@@ -146,7 +146,81 @@ class OptionApi(BaseApi):
             _errors = None
         
         _result = ApiResponse(_response, body=decoded, errors=_errors)
-        return _result 
+        return _result
+
+    def add_multiple_options(self, payload):
+        _url_path = f'/option/multiple'
+        _query_builder = self.config.get_base_uri()
+        _query_builder += _url_path 
+        _query_url = ApiHelper.clean_url(_query_builder)
+
+        _headers = { 
+            'accept': 'application/json',
+            'Content-Type': 'application/json'
+        }
+
+        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=ApiHelper.json_serialize(payload))
+        OAuth2.apply(self.config, _request) 
+        _response = self.execute_request(_request) 
+
+        _url_path = f'/item/{item_id}/modifier/{modifier_id}'
+        _query_builder = self.config.get_base_uri()
+        _query_builder += _url_path 
+        _query_url = ApiHelper.clean_url(_query_builder)
+
+        _headers = {
+            'accept': 'application/json'
+        }
+
+        _request = self.config.http_client.post(_query_url, headers=_headers) 
+        OAuth2.apply(self.config, _request)
+        _response = self.execute_request(_request)
+
+        decoded = ApiHelper.json_deserialize(_response.text)
+        if type(decoded) == dict: 
+            _errors = decoded.get('error')
+        else: 
+            _errors = None
+        
+        _result = ApiResponse(_response, body=decoded, errors=_errors)
+        return _result
+
+    def delete_multiple_options(self, payload):
+        _url_path = f'/option/multiple'
+        _query_builder = self.config.get_base_uri()
+        _query_builder += _url_path 
+        _query_url = ApiHelper.clean_url(_query_builder)
+
+        _headers = { 
+            'accept': 'application/json',
+            'Content-Type': 'application/json'
+        }
+
+        _request = self.config.http_client.delete(_query_url, headers=_headers, parameters=ApiHelper.json_serialize(payload))
+        OAuth2.apply(self.config, _request) 
+        _response = self.execute_request(_request) 
+
+        _url_path = f'/item/{item_id}/modifier/{modifier_id}'
+        _query_builder = self.config.get_base_uri()
+        _query_builder += _url_path 
+        _query_url = ApiHelper.clean_url(_query_builder)
+
+        _headers = {
+            'accept': 'application/json'
+        }
+
+        _request = self.config.http_client.post(_query_url, headers=_headers) 
+        OAuth2.apply(self.config, _request)
+        _response = self.execute_request(_request)
+
+        decoded = ApiHelper.json_deserialize(_response.text)
+        if type(decoded) == dict: 
+            _errors = decoded.get('error')
+        else: 
+            _errors = None
+        
+        _result = ApiResponse(_response, body=decoded, errors=_errors)
+        return _result
 
 
 
